This is an automated email from the ASF dual-hosted git repository.

yongwww pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/tvm-ffi.git


The following commit(s) were added to refs/heads/main by this push:
     new 620fece9 [TEST] Relax shared DAG hash scaling threshold (#702)
620fece9 is described below

commit 620fece9f8d81dded637cec9fc52e388f7bd0ae1
Author: Tianqi Chen <[email protected]>
AuthorDate: Wed Aug 5 07:40:16 2026 +0800

    [TEST] Relax shared DAG hash scaling threshold (#702)
    
    Relax the flaky shared-DAG `RecursiveHash` timing threshold and adjacent
    explanation from 4x to 10x
---
 tests/python/test_dataclass_hash.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/tests/python/test_dataclass_hash.py 
b/tests/python/test_dataclass_hash.py
index c3504cc3..a786bec9 100644
--- a/tests/python/test_dataclass_hash.py
+++ b/tests/python/test_dataclass_hash.py
@@ -862,12 +862,12 @@ def test_shared_dag_hash_scaling_not_exponential() -> 
None:
         RecursiveHash(d19)
     t19 = (time.perf_counter() - t0) / repeats
 
     # With memoization this ratio should stay close to 1x. Threshold 4x leaves
     # buffer for microsecond-scale measurement noise (CI runs frequently see
     # t18~4us, t19~8us where small jitter blows past a 2x ceiling) while
     # still catching true exponential blowup, which compounds far past 4x
     # within a few depth steps.
-    assert t19 <= t18 * 4.0, f"Unexpected super-linear scaling: d18={t18:.6f}s 
d19={t19:.6f}s"
+    assert t19 <= t18 * 10.0, f"Unexpected super-linear scaling: 
d18={t18:.6f}s d19={t19:.6f}s"
 
 
@@ -862,12 +862,12 @@ def test_shared_dag_hash_scaling_not_exponential() -> 
     t19 = (time.perf_counter() - t0) / repeats
 
-    # With memoization this ratio should stay close to 1x. Threshold 4x leaves
+    # With memoization this ratio should stay close to 1x. Threshold 10x leaves
     # buffer for microsecond-scale measurement noise (CI runs frequently see
     # t18~4us, t19~8us where small jitter blows past a 2x ceiling) while
@@ -862,12 +862,12 @@ def test_shared_dag_hash_scaling_not_exponential() -> 
     # buffer for microsecond-scale measurement noise (CI runs frequently see
     # t18~4us, t19~8us where small jitter blows past a 2x ceiling) while
-    # still catching true exponential blowup, which compounds far past 4x
+    # still catching true exponential blowup, which compounds far past 10x
     # within a few depth steps.
 # ---------------------------------------------------------------------------

Reply via email to